@@ -24,7 +24,9 @@
 #include <gtk/gtkstock.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-login-dialog.h>
-#include "gnome-db-intl.h"
+#include <libgnomedb/gnome-db-stock.h>
+#include <libgnomeui/gnome-window-icon.h>
+#include <bonobo/bonobo-i18n.h>
 
 struct _GnomeDbLoginDialogPrivate {
 	GtkWidget *login;
@@ -77,6 +79,8 @@ gnome_db_login_dialog_class_init (GnomeDbLoginDialogClass *klass)
 	g_object_class_install_property (
 		object_class, PROP_PASSWORD,
 		g_param_spec_string ("password", NULL, NULL, NULL, G_PARAM_READABLE));
+
+	gnome_db_stock_init ();
 }
 
 static void
@@ -87,7 +91,7 @@ gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass
 	dialog->priv = g_new0 (GnomeDbLoginDialogPrivate, 1);
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_OK, GTK_RESPONSE_OK);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GNOME_DB_STOCK_CONNECT, GTK_RESPONSE_OK);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	dialog->priv->login = gnome_db_login_new (NULL);
@@ -192,7 +196,7 @@ gnome_db_login_dialog_new (const gchar *title)
 	dialog = g_object_new (GNOME_DB_TYPE_LOGIN_DIALOG, NULL);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
 	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
-					 LIBGNOMEDB_PIXMAPSDIR "/gnome-db.png");
+					 LIBGNOMEDB_ICONSDIR "/gnome-db.png");
 
 	return GTK_WIDGET (dialog);
 }
